Contributors
============

- Ivan Konovalov (`@ivknv <https://github.com/ivknv>`_) (author, maintainer)
- Yuri Kobets (`@tordex <https://github.com/tordex>`_)
- Vladislav (`@Omnivanitate <https://github.com/Omnivanitate>`_)
- `@unix3dgforce <https://github.com/unix3dgforce>`_
- Nikita Kolesov (`@NikitaKolesov <https://github.com/NikitaKolesov>`_)
- Katant Savelev (`@KatantDev <https://github.com/KatantDev>`_)
